@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 import sys
+
 import pycksum
 
 
@@ -17,10 +18,8 @@ def main():
                 break
             c.add(data)
 
-        try:
-            eval("""print "%d %d %s" %  (c.get_cksum(), c.get_size(), fname)""")
-        except SyntaxError:
-            print("%d %d %s" % (c.get_cksum(), c.get_size(), fname))
+        print("%d %d %s" % (c.get_cksum(), c.get_size(), fname))
+
 
 if __name__ == "__main__":
     main()
